import { CommonTableColumn } from '~/common'
import type { CellSlotProps } from '../type'

type RowClassGetter = (param: {
  columns: CommonTableColumn[]
  rowData: any
  rowIndex: number
}) => string

type CellClassGetter = (param: CellSlotProps) => string

const defaultCellClassV2 = 'el-table-v2__cell-text'

export default function useTableStyle(tableName?: string) {
  const rowClass = ({ row, rowIndex }) => {
    const classes: string[] = []
    if (tableName?.includes('FlightContainer')) {
      if (rowIndex === 1) {
        classes.push('row-warning')
      }
    }
    if (tableName?.includes('FlightWaybill')) {
      if (rowIndex === 0) {
        classes.push('row-alarm')
      }
      if (rowIndex === 1) {
        classes.push('row-warning')
      }
    }
    return classes.join(' ')
  }

  const cellClass = ({ row, column, rowIndex, columnIndex }) => {
    const classes: string[] = []
    if (tableName?.includes('FlightContainer')) {
      if (['C0'].includes(column.property)) {
        classes.push('cell-click')
      }
    }
    if (tableName?.includes('FlightWaybill')) {
      if (['C0'].includes(column.property)) {
        classes.push('cell-click')
      }
    }
    if (tableName === 'DepartureFlightWaybill') {
      if (['C1'].includes(column.property)) {
        classes.push('cell-click')
      }
    }
    if (tableName === 'InternationalDepartureFlightWaybill') {
      if (['C2'].includes(column.property)) {
        classes.push('cell-click')
      }
    }
    if (tableName?.includes('DepartureWaybillGoods')) {
      if (['C2'].includes(column.property)) {
        classes.push('cell-click')
      }
    }
    if (tableName?.includes('ArrivalWaybillGoods')) {
      if (['C1'].includes(column.property)) {
        classes.push('cell-click')
      }
    }
    return classes.join(' ')
  }

  const rowClassV2: RowClassGetter = ({ columns, rowData, rowIndex }) => {
    const classes: string[] = []
    if (tableName?.includes('Airport')) {
      if (rowIndex <= 1) {
        classes.push('bg-gray')
      }
      if (rowIndex === 1) {
        classes.push('underline-red')
      }
    }
    return classes.join(' ')
  }

  const cellClassV2: CellClassGetter = ({
    column,
    columns,
    columnIndex,
    rowData,
    rowIndex,
  }) => {
    const classes: string[] = [defaultCellClassV2]
    if (['4/243', '0/6'].includes(rowData[column.columnName])) {
      classes.push('cell-warning')
    }
    if (['5/357'].includes(rowData[column.columnName])) {
      classes.push('cell-alarm')
    }
    if (['flightNO'].includes(column.columnName)) {
      classes.push('cell-click')
    }
    return classes.join(' ')
  }

  return {
    rowClass,
    cellClass,
    rowClassV2,
    cellClassV2,
  }
}
